class Game():
    def __init__(self, id, name, year_first_release, is_bootleg):
        self.id = id
        self.name = name
        self.year_first_release = year_first_release
        self.is_bootleg = is_bootleg